.. localconfig documentation master file, created by
   sphinx-quickstart on Thu Jan  1 11:39:24 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to localconfig's documentation!
=======================================

.. toctree::
   :maxdepth: 2

   README

API Documentation
=================

.. toctree::
   :maxdepth: 2

   localconfig
   utils

Change Log
=================

.. toctree::
   :maxdepth: 1

   CHANGELOG

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

